Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5699)

Unified Diff: chromeos/chromeos_switches.cc

Issue 1887953002: Revert of [Merge to M50] Enable bootstrapping feature by default. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2661
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/chromeos_switches.h ('k') | components/pairing/bluetooth_host_pairing_controller.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/chromeos_switches.cc
diff --git a/chromeos/chromeos_switches.cc b/chromeos/chromeos_switches.cc
index 348e2323d0d4947ff23b4af9f18e9a48cbf23aa4..afb9b83f74630d4103379bcfcc0b423039e549f3 100644
--- a/chromeos/chromeos_switches.cc
+++ b/chromeos/chromeos_switches.cc
@@ -254,8 +254,9 @@
// Indicates that a guest session has been started before OOBE completion.
const char kOobeGuestSession[] = "oobe-guest-session";
// Indicates that if we should start bootstrapping Master OOBE.
const char kOobeBootstrappingMaster[] = "oobe-bootstrapping-master";
+const char kOobeBootstrappingSlave[] = "oobe-bootstrapping-slave";
// Specifies power stub behavior:
// 'cycle=2' - Cycles power states every 2 seconds.
« no previous file with comments | « chromeos/chromeos_switches.h ('k') | components/pairing/bluetooth_host_pairing_controller.h » ('j') | no next file with comments »
@@ -254,8 +254,9 @@
// Indicates that a guest session has been started before OOBE completion.
const char kOobeGuestSession[] = "oobe-guest-session";
-// Indicates that if we should start bootstrapping Master OOBE.
+// Indicates that if we should start bootstrapping Master/Slave OOBE.
const char kOobeBootstrappingMaster[] = "oobe-bootstrapping-master";

Powered by Google App Engine
This is Rietveld 408576698